=== removed file 'build-stamp'
=== removed file 'configure-stamp'
=== removed file 'debian/files'
--- debian/files	2013-08-08 15:58:44 +0000
+++ debian/files	1970-01-01 00:00:00 +0000
@@ -1,3 +0,0 @@
-ubuntu-keyboard_0.99.trunk.phablet1_armhf.deb libs extra
-ubuntu-keyboard-data_0.99.trunk.phablet1_all.deb libs extra
-ubuntu-keyboard-tests_0.99.trunk.phablet1_armhf.deb libs extra

=== modified file 'qml/Keyboard.qml'
--- qml/Keyboard.qml	2013-08-09 15:22:29 +0000
+++ qml/Keyboard.qml	2013-08-13 03:11:49 +0000
@@ -39,6 +39,7 @@
     property alias title: keyboard_title.text
 
     visible: layout.visible
+    readonly property var layoutState: layout.keyboard_state
 
     property int contentOrientation: Qt.PrimaryOrientation
 
@@ -57,6 +58,10 @@
             console.debug("title:" + layout.title)
             title_timeout.start()
         }
+
+        onStateChanged: {
+            console.error("State Changed: " + layout.keyboard_state)
+        }
     }
 
     MouseArea {
@@ -125,6 +130,7 @@
             }
 
             Item {
+                objectName: "keyboardKeypad"
                 id: keyPad
 
                 anchors.top: borderTop.bottom
@@ -159,6 +165,7 @@
 
                         Text {
                             id: key_text_item
+                            property var action_type: key_action_type
 
                             anchors.fill: parent
                             text: key_text

=== modified file 'src/lib/logic/layouthelper.h'
--- src/lib/logic/layouthelper.h	2013-07-19 12:05:07 +0000
+++ src/lib/logic/layouthelper.h	2013-08-13 03:11:49 +0000
@@ -35,6 +35,7 @@
 #include "models/key.h"
 #include "models/keyarea.h"
 #include "models/wordribbon.h"
+#include "models/layout.h"
 
 #include <QtCore>
 
@@ -143,6 +144,7 @@
     Q_SLOT void onKeysOverriden(const Logic::KeyOverrides &overriden_keys,
                                 bool update);
 
+    Q_SIGNAL void stateChanged(Model::Layout::State state);
 private:
     const QScopedPointer<LayoutHelperPrivate> d_ptr;
 };

=== modified file 'src/lib/logic/layoutupdater.cpp'
--- src/lib/logic/layoutupdater.cpp	2013-08-09 15:22:29 +0000
+++ src/lib/logic/layoutupdater.cpp	2013-08-13 03:11:49 +0000
@@ -733,6 +733,13 @@
     converter.setLayoutOrientation(orientation);
     d->layout->setCenterPanel(d->inShiftedState() ? converter.shiftedKeyArea()
                                                   : converter.keyArea());
+
+    if (d->inShiftedState())
+        Q_EMIT d->layout->stateChanged(Model::Layout::ShiftedState);
+    else if (d->inDeadkeyState())
+        Q_EMIT d->layout->stateChanged(Model::Layout::DeadkeyState);
+    else
+        Q_EMIT d->layout->stateChanged(Model::Layout::DefaultState);
 }
 
 void LayoutUpdater::switchToPrimarySymView()
@@ -750,6 +757,8 @@
 
     // Reset shift state machine, also see switchToMainView.
     d->shift_machine.restart();
+
+    Q_EMIT d->layout->stateChanged(Model::Layout::PrimarySymbolState);
 }
 
 void LayoutUpdater::switchToSecondarySymView()
@@ -764,6 +773,8 @@
     KeyAreaConverter converter(d->style->attributes(), &d->loader);
     converter.setLayoutOrientation(orientation);
     d->layout->setCenterPanel(converter.symbolsKeyArea(1));
+
+    Q_EMIT d->layout->stateChanged(Model::Layout::SecondarySymbolState);
 }
 
 void LayoutUpdater::switchToAccentedView()

=== modified file 'src/lib/models/layout.cpp'
--- src/lib/models/layout.cpp	2013-08-09 15:22:29 +0000
+++ src/lib/models/layout.cpp	2013-08-13 03:11:49 +0000
@@ -63,6 +63,7 @@
     KeyArea key_area;
     QString image_directory;
     QHash<int, QByteArray> roles;
+    Layout::State state;
     QString activeViewId;
 
     explicit LayoutPrivate();
@@ -74,6 +75,7 @@
     , key_area()
     , image_directory()
     , roles()
+    , state(Layout::DefaultState)
 {
     // Model roles are used as variables in QML, hence the under_score naming
     // convention:
@@ -88,6 +90,7 @@
     roles[Layout::RoleKeyFontStretch] = "key_font_stretch";
     roles[Layout::RoleKeyIcon] = "key_icon";
     roles[Layout::RoleKeyActionInsert] = "key_action_insert";
+    roles[Layout::RoleKeyAction] = "key_action_type";
 }
 
 
@@ -230,6 +233,18 @@
                     qGuiApp->primaryScreen()->orientation()) );
 }
 
+Layout::State Layout::state() const
+{
+    Q_D(const Layout);
+    return d->state;
+}
+
+void Layout::setState(Model::Layout::State state)
+{
+    Q_D(Layout);
+    d->state = state;
+    Q_EMIT stateChanged(state);
+}
 
 QString Layout::activeView() const
 {
@@ -321,6 +336,9 @@
 
     case RoleKeyActionInsert:
         return QVariant(key.action() == Key::ActionInsert);
+
+    case RoleKeyAction:
+        return QVariant(key.action());
     }
 
     qWarning() << __PRETTY_FUNCTION__

=== modified file 'src/lib/models/layout.h'
--- src/lib/models/layout.h	2013-08-09 15:22:29 +0000
+++ src/lib/models/layout.h	2013-08-13 03:11:49 +0000
@@ -78,11 +78,22 @@
     Q_PROPERTY(int invisible_toucharea_height READ invisibleTouchAreaHeight
                                          NOTIFY invisibleTouchAreaHeightChanged)
 
+    Q_PROPERTY(State keyboard_state READ state WRITE setState
+                            NOTIFY stateChanged)
     Q_PROPERTY(QString activeView READ activeView WRITE setActiveView
                                          NOTIFY activeViewChanged)
 
+    Q_ENUMS(State)
 
 public:
+    enum State {
+        DefaultState,
+        ShiftedState,
+        PrimarySymbolState,
+        SecondarySymbolState,
+        DeadkeyState
+    };
+
     enum Roles {
         RoleKeyRectangle = Qt::UserRole + 1,
         RoleKeyReactiveArea,
@@ -94,7 +105,8 @@
         RoleKeyFontSize,
         RoleKeyFontStretch,
         RoleKeyIcon,
-        RoleKeyActionInsert
+        RoleKeyActionInsert,
+        RoleKeyAction   // Extra introspection detail for testing.
     };
 
     explicit Layout(QObject *parent = 0);
@@ -137,6 +149,10 @@
     Q_SLOT int invisibleTouchAreaHeight() const;
     Q_SIGNAL void invisibleTouchAreaHeightChanged(int &changed);
 
+    Q_SLOT State state() const;
+    Q_SLOT void setState(Model::Layout::State state);
+    Q_SIGNAL void stateChanged(Model::Layout::State state);
+
     Q_SLOT QString activeView() const;
     Q_SLOT void setActiveView(const QString& activeViewId);
     Q_SIGNAL void activeViewChanged(const QString &activeViewId);

=== modified file 'src/plugin/inputmethod.cpp'
--- src/plugin/inputmethod.cpp	2013-08-09 16:09:07 +0000
+++ src/plugin/inputmethod.cpp	2013-08-13 03:11:49 +0000
@@ -245,6 +245,9 @@
     QObject::connect(&layout.updater, SIGNAL(languageChanged(QString)),
                      &editor,  SLOT(onLanguageChanged(const QString&)));
 
+    QObject::connect(&layout.helper, SIGNAL(stateChanged(Model::Layout::State)),
+                     &layout.model,  SLOT(setState(Model::Layout::State)));
+
 #ifdef EXTENDED_SURFACE_TEMP_DISABLED
     QObject::connect(&layout.event_handler,          SIGNAL(extendedKeysShown(Key)),
                      &extended_layout.event_handler, SLOT(onExtendedKeysShown(Key)));

=== added directory 'tests/autopilot'
=== added directory 'tests/autopilot/maliit_keyboard'
=== added file 'tests/autopilot/maliit_keyboard/__init__.py'
=== added directory 'tests/autopilot/maliit_keyboard/emulators'
=== added file 'tests/autopilot/maliit_keyboard/emulators/__init__.py'
=== added file 'tests/autopilot/maliit_keyboard/emulators/osk.py'
--- tests/autopilot/maliit_keyboard/emulators/osk.py	1970-01-01 00:00:00 +0000
+++ tests/autopilot/maliit_keyboard/emulators/osk.py	2013-08-13 03:11:49 +0000
@@ -0,0 +1,259 @@
+from time import sleep
+
+from autopilot.input import Pointer, Touch
+from autopilot.introspection import get_proxy_object_for_existing_process
+
+
+# Definitions of enums used within the cpp source code.
+KB_STATE_DEFAULT = 0
+KB_STATE_SHIFTED = 1
+KB_STATE_SYMBOL_1 = 2
+KB_STATE_SYMBOL_2 = 3
+
+ACTION_SHIFT = 1
+ACTION_BACKSPACE = 2
+ACTION_SPACE = 3
+ACTION_SYM = 6
+ACTION_RETURN = 7
+ACTION_SWITCH = 11
+
+# Moved '/' to primary symbol, default layout can have a .com instead.
+default_keys = "qwertyuiopasdfghjklzxcvbnm."
+shifted_keys = "QWERTYUIOPASDFGHJKLZXCVBNM."
+primary_symbol = "1234567890*#+-=()!?@~/\\';:,."
+# This is _not_ a complete list for this screen.
+secondary_symbol = "$%<>[]`^|_{}\"&"
+
+# Are we able to reset the keyboard some how? So that there is a addCleanup
+# that resets the keyboard to a known state? This means that we won't have to
+# ensure in setUp that we are in the correct state etc.
+
+class OSKUnsupportedKey(RuntimeError):
+    pass
+
+
+class OSK(object):
+
+    def __init__(self, pointer=None):
+        try:
+            maliit = get_proxy_object_for_existing_process(
+                connection_name='org.maliit.server'
+            )
+        except RuntimeError:
+            raise RuntimeError(
+                "Unable to find maliit-server dbus object. Has it been started"
+                "with introspection enabled?"
+            )
+        self.keyboard = maliit.select_single("Keyboard")
+        self.keypad = maliit.select_single(
+            "QQuickItem",
+            objectName="keyboardKeypad"
+        )
+
+        # Contains instructions on how to move the keyboard into a specific
+        # state/layout so that we can successfully press the required key.
+        self._state_lookup_table = self._generate_state_lookup_table()
+
+        if pointer is None:
+            self.pointer = Pointer(Touch.create())
+        else:
+            self.pointer = pointer
+
+    def dismiss(self):
+        """Attempt to swipe the keyboard down so that it is hidden."""
+        if self.is_available:
+            x, y, h, w = self.keyboard.globalRect
+            x_pos = int(w / 2)
+            # start_y: just inside the keyboard, must be a better way than +1px
+            start_y = y + 1
+            end_y = y + int(h / 2)
+            self.pointer.drag(x_pos, start_y, x_pos, end_y)
+
+            self.keyboard.state.wait_for("HIDDEN")
+
+    def is_available(self):
+        """Returns wherever the keyboard is shown and ready to use."""
+        return (
+            self.keyboard.state == "SHOWN"
+            and self.keyboard.hideAnimationFinished == False
+        )
+
+
+    def press_key(self, key):
+        if not self.is_available():
+            raise RuntimeError("Keyboard is not on screen")
+
+        if self._is_special_key(key):
+            self._press_special_key(key)
+        else:
+            required_state_for_key = self._get_keys_required_state(key)
+            self._switch_keyboard_to_state(required_state_for_key)
+
+            key = self.keypad.select_single('QQuickText', text=key)
+            self.pointer.click_object(key)
+
+
+    def type(self, string, delay=0.1):
+        """Only 'normal' or single characters can be typed this way."""
+        for char in string:
+            self.press_key(char)
+            sleep(delay)
+
+    def _get_keys_required_state(self, char):
+        """Given a character determine which state the keyboard needs to be in
+        so that it is visible and can be clicked.
+
+        """
+        # '.' as it is available on all screens (currently)
+        # '/' is available on more than 1 screen.
+        if char in default_keys:
+            return KB_STATE_DEFAULT
+        elif char in shifted_keys:
+            return KB_STATE_SHIFTED
+        elif char in primary_symbol:
+            return KB_STATE_SYMBOL_1
+        elif char in secondary_symbol:
+            return KB_STATE_SYMBOL_2
+        else:
+            raise OSKUnsupportedKey(
+                "Don't know which state key '%s' requires" % char
+            )
+
+    def _switch_keyboard_to_state(self, target_state):
+        """Given a target_state, presses the required keys to bring the
+        keyboard into the correct state.
+
+        :raises: *RuntimeError* if unable to change the keyboard into the
+          expected state.
+
+        """
+        current_state = self.keyboard.layoutState
+
+        if target_state == current_state:
+            return
+
+        instructions = self._state_lookup_table[target_state].get(
+            current_state,
+            None
+        )
+        if instructions is None:
+            raise RuntimeError(
+                "Don't know how to get to state %d from current state (%d)"
+                % (target_state, current_state)
+            )
+
+        for step in instructions:
+            key, expected_state = step
+            # Veebers todo: just use press_key here, need to update the lookup
+            # too.
+            self._press_special_key(key)
+            # self.press_key(key)
+            self.keyboard.layoutState.wait_for(expected_state)
+
+    def _press_special_key(self, key_label):
+        """Press a named special key like Delete, Shift or ?123/ i.e. keys that
+        don't necessarily have text names or are multi-character named.
+
+        """
+
+        key = None
+        uppercase_key_label = key_label.upper()
+        if uppercase_key_label == "\b":
+            key = self.keypad.select_single(
+                'QQuickText',
+                action_type=ACTION_BACKSPACE
+            )
+        elif uppercase_key_label == "\n":
+            key = self.keypad.select_single(
+                'QQuickText',
+                action_type=ACTION_RETURN
+            )
+        elif key_label == " ":
+            key = self.keypad.select_single(
+                'QQuickText',
+                action_type=ACTION_SPACE
+            )
+        elif uppercase_key_label == "SHIFT":
+            key = self.keypad.select_single(
+                'QQuickText',
+                action_type=ACTION_SHIFT
+            )
+        elif key_label in ["?123", "ABC", "1/2", "2/2"]:
+            # These aren't really special keys, now the xpathselect bug has
+            # been sorted.
+            key = self.keypad.select_single('QQuickText', text=key_label)
+
+        if key is None:
+            raise OSKUnsupportedKey(
+                "Attempting to push an unknown 'special' key: '%s'" % key_label
+            )
+
+        # Get required state for the key to be pushed (i.e not '\b', '\n', ' '
+        # as they are always available.)
+
+        self.pointer.click_object(key)
+
+    def _is_special_key(self, key):
+        return key in ["\n", "\b", " ", "SHIFT", "?123", "ABC", "1/2", "2/2"]
+
+    # Give the state that you want and the current state, get instructions on how
+    # to move to that state.
+    # lookup_table[REQUESTED_STATE][CURRENT_STATE] -> Instructions(Key to press,
+    #   Expected state after key press.)
+    def _generate_state_lookup_table(self):
+        state_lookup_table = [
+            # KB_STATE_DEFAULT
+            {
+                KB_STATE_SHIFTED: [
+                    ("SHIFT", KB_STATE_DEFAULT)
+                ],
+                KB_STATE_SYMBOL_1: [
+                    ("ABC", KB_STATE_DEFAULT)
+                ],
+                KB_STATE_SYMBOL_2: [
+                    ("ABC", KB_STATE_DEFAULT)
+                ],
+            },
+            # KB_STATE_SHIFTED
+            {
+                KB_STATE_DEFAULT: [
+                    ("SHIFT", KB_STATE_SHIFTED)
+                ],
+                KB_STATE_SYMBOL_1: [
+                    ("ABC", KB_STATE_DEFAULT),
+                    ("SHIFT", KB_STATE_SHIFTED)
+                ],
+                KB_STATE_SYMBOL_2: [
+                    ("ABC", KB_STATE_DEFAULT),
+                    ("SHIFT", KB_STATE_SHIFTED)
+                ],
+            },
+            # KB_STATE_SYMBOL_1
+            {
+                KB_STATE_DEFAULT: [
+                    ("?123", KB_STATE_SYMBOL_1)
+                ],
+                KB_STATE_SHIFTED: [
+                    ("?123", KB_STATE_SYMBOL_1)
+                ],
+                KB_STATE_SYMBOL_2: [
+                    ("2/2", KB_STATE_SYMBOL_1)
+                ],
+            },
+            # KB_STATE_SYMBOL_2
+            {
+                KB_STATE_DEFAULT: [
+                    ("?123", KB_STATE_SYMBOL_1),
+                    ("1/2", KB_STATE_SYMBOL_2)
+                ],
+                KB_STATE_SHIFTED: [
+                    ("?123", KB_STATE_SYMBOL_1),
+                    ("1/2", KB_STATE_SYMBOL_2)
+                ],
+                KB_STATE_SYMBOL_1: [
+                    ("1/2", KB_STATE_SYMBOL_2)
+                ],
+            },
+        ]
+
+        return state_lookup_table

=== added file 'tests/autopilot/maliit_keyboard/kb_1-aug.log'
--- tests/autopilot/maliit_keyboard/kb_1-aug.log	1970-01-01 00:00:00 +0000
+++ tests/autopilot/maliit_keyboard/kb_1-aug.log	2013-08-13 03:11:49 +0000
@@ -0,0 +1,7030 @@
+(Finding proxy object)
+(Introspecting)
+ maliit-server 'None' 
+
+ > Children: Array([dbus.String(u'QQuickView')], signature=None)
+ > id: 1
+--- QQuickView '' 
+
+--- > status: 1
+--- > minimumWidth: 0
+--- > objectName: 
+--- > color: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+--- > contentOrientation: 0
+--- > maximumHeight: 16777215
+--- > height: 589
+--- > visible: 1
+--- > x: 0
+--- > minimumHeight: 0
+--- > id: 8
+--- > maximumWidth: 16777215
+--- > resizeMode: 1
+--- > title: 
+--- > _autopilot_id: 8
+--- > modality: 0
+--- > width: 720
+--- > role: 7
+--- > source: file:///usr/share/maliit/plugins/org/maliit/maliit-keyboard.qml
+--- > y: 691
+--- > flags: 2361344
+--- > Children: Array([dbus.String(u'QQmlEngine'), dbus.String(u'QQmlComponent'), dbus.String(u'QQuickRootItem')], signature=None)
+------ Keyboard '' 
+
+------ > opacity: 1.0
+------ > hideAnimationFinished: 0
+------ > clip: 0
+------ > enabled: 1
+------ > baselineOffset: 0.0
+------ > focus: 0
+------ > implicitHeight: 0.0
+------ > height: 589.0
+------ > visible: 1
+------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(691, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(589, variant_level=1)], signature=None)
+------ > rotation: 0.0
+------ > id: 2
+------ > pressedKeyIndex: -1
+------ > hidePropertyAnimationFinished: 0
+------ > shown: 1
+------ > scale: 1.0
+------ > objectName: 
+------ > activeFocus: 0
+------ > antialiasing: 0
+------ > area_enabled: 1
+------ > title: 
+------ > smooth: 1
+------ > transformOrigin: 4
+------ > width: 720.0
+------ > state: SHOWN
+------ > implicitWidth: 0.0
+------ > _autopilot_id: 2
+------ > y: 0.0
+------ > x: 0.0
+------ > z: 0.0
+------ > Children: Array([dbus.String(u'QQuickTransition'), dbus.String(u'QQuickState'), dbus.String(u'QQuickState'), dbus.String(u'RotationHelper_QMLTYPE_0'), dbus.String(u'RotationHelper_QMLTYPE_0')], signature=None)
+--------- RotationHelper '' 
+
+--------- > opacity: 1.0
+--------- > clip: 0
+--------- > enabled: 1
+--------- > baselineOffset: 0.0
+--------- > focus: 0
+--------- > implicitHeight: 0.0
+--------- > __rotationString: 0
+--------- > visible: 1
+--------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(691, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(589, variant_level=1)], signature=None)
+--------- > rotation: 0.0
+--------- > height: 589.0
+--------- > id: 5
+--------- > scale: 1.0
+--------- > objectName: 
+--------- > activeFocus: 0
+--------- > antialiasing: 0
+--------- > _autopilot_id: 5
+--------- > smooth: 1
+--------- > transformOrigin: 4
+--------- > width: 720.0
+--------- > state: 
+--------- > implicitWidth: 0.0
+--------- > y: 0.0
+--------- > x: 0.0
+--------- > z: 0.0
+--------- > Children: Array([dbus.String(u'QQuickItem'), dbus.String(u'QQmlConnections'), dbus.String(u'QQuickMouseArea_QML_6'), dbus.String(u'QQuickScreenAttached'), dbus.String(u'QQuickItem'), dbus.String(u'QQuickMouseArea_QML_6')], signature=None)
+------------ QQuickItem '' 
+
+------------ > opacity: 1.0
+------------ > clip: 0
+------------ > enabled: 1
+------------ > baselineOffset: 0.0
+------------ > focus: 0
+------------ > implicitHeight: 0.0
+------------ > height: 0.0
+------------ > visible: 1
+------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(691, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------ > rotation: 0.0
+------------ > id: 6
+------------ > scale: 1.0
+------------ > objectName: 
+------------ > activeFocus: 0
+------------ > antialiasing: 0
+------------ > _autopilot_id: 6
+------------ > smooth: 1
+------------ > transformOrigin: 4
+------------ > width: 0.0
+------------ > state: 0
+------------ > implicitWidth: 0.0
+------------ > y: 0.0
+------------ > x: 0.0
+------------ > z: 0.0
+------------ > Children: Array([dbus.String(u'QQuickState'), dbus.String(u'QQuickState')], signature=None)
+------------ QQuickMouseArea '' 
+
+------------ > propagateComposedEvents: 0
+------------ > clip: 0
+------------ > enabled: 1
+------------ > baselineOffset: 0.0
+------------ > focus: 0
+------------ > implicitHeight: 0.0
+------------ > height: 589.0
+------------ > visible: 1
+------------ > pressedButtons: 0
+------------ > id: 7
+------------ > acceptedButtons: 1
+------------ > scale: 1.0
+------------ > activeFocus: 0
+------------ > transformOrigin: 4
+------------ > cursorShape: 0
+------------ > width: 720.0
+------------ > state: 
+------------ > implicitWidth: 0.0
+------------ > jumpBackThreshold: 170
+------------ > containsMouse: 0
+------------ > opacity: 1.0
+------------ > objectName: 
+------------ > mouseY: 0.0
+------------ > preventStealing: 0
+------------ > hoverEnabled: 0
+------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(691, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(589, variant_level=1)], signature=None)
+------------ > rotation: 0.0
+------------ > antialiasing: 0
+------------ > _autopilot_id: 7
+------------ > smooth: 1
+------------ > pressed: 0
+------------ > y: 0.0
+------------ > x: 0.0
+------------ > z: 0.0
+------------ > Children: Array([dbus.String(u'QQuickRectangle'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickPropertyAnimation'), dbus.String(u'QQuickRectangle'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------ > mouseX: 0.0
+--------------- QQuickRectangle '' 
+
+--------------- > opacity: 1.0
+--------------- > clip: 0
+--------------- > color: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+--------------- > enabled: 1
+--------------- > baselineOffset: 0.0
+--------------- > focus: 0
+--------------- > implicitHeight: 0.0
+--------------- > height: 0.0
+--------------- > visible: 1
+--------------- > radius: 0.0
+--------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+--------------- > rotation: 0.0
+--------------- > id: 9
+--------------- > scale: 1.0
+--------------- > objectName: 
+--------------- > activeFocus: 0
+--------------- > antialiasing: 0
+--------------- > _autopilot_id: 9
+--------------- > smooth: 1
+--------------- > transformOrigin: 4
+--------------- > width: 720.0
+--------------- > state: NORMAL
+--------------- > implicitWidth: 0.0
+--------------- > y: 122.0
+--------------- > x: 0.0
+--------------- > z: 0.0
+--------------- > Children: Array([dbus.String(u'QQuickState'), dbus.String(u'QQuickState'), dbus.String(u'QQuickRectangle'), dbus.String(u'QQuickListView'), dbus.String(u'QQmlComponent'), dbus.String(u'QQuickRectangle'), dbus.String(u'QQuickListView')], signature=None)
+------------------ QQuickRectangle '' 
+
+------------------ > opacity: 1.0
+------------------ > clip: 0
+------------------ > color: Array([dbus.Int32(241, variant_level=1), dbus.Int32(241, variant_level=1), dbus.Int32(241, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------ > enabled: 1
+------------------ > baselineOffset: 0.0
+------------------ > focus: 0
+------------------ > implicitHeight: 0.0
+------------------ > height: 0.0
+------------------ > visible: 1
+------------------ > radius: 0.0
+------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------ > rotation: 0.0
+------------------ > id: 11
+------------------ > scale: 1.0
+------------------ > objectName: 
+------------------ > activeFocus: 0
+------------------ > antialiasing: 0
+------------------ > _autopilot_id: 11
+------------------ > smooth: 1
+------------------ > transformOrigin: 4
+------------------ > width: 720.0
+------------------ > state: 
+------------------ > implicitWidth: 0.0
+------------------ > y: 0.0
+------------------ > x: 0.0
+------------------ > z: 0.0
+------------------ QQuickListView '' 
+
+------------------ > baselineOffset: 0.0
+------------------ > focus: 0
+------------------ > flickableDirection: 1
+------------------ > height: 0.0
+------------------ > visible: 1
+------------------ > draggingVertically: 0
+------------------ > contentHeight: -1.0
+------------------ > layoutDirection: 0
+------------------ > preferredHighlightEnd: 0.0
+------------------ > verticalVelocity: 0.0
+------------------ > transformOrigin: 4
+------------------ > width: 720.0
+------------------ > pixelAligned: 0
+------------------ > flicking: 0
+------------------ > atYEnd: 1
+------------------ > highlightRangeMode: 0
+------------------ > objectName: 
+------------------ > cacheBuffer: 320
+------------------ > atXBeginning: 1
+------------------ > contentX: -0.0
+------------------ > rotation: 0.0
+------------------ > bottomMargin: 0.0
+------------------ > highlightResizeDuration: -1
+------------------ > count: 0
+------------------ > originY: 0.0
+------------------ > boundsBehavior: 2
+------------------ > pressDelay: 0
+------------------ > currentSection: 
+------------------ > smooth: 1
+------------------ > verticalLayoutDirection: 2
+------------------ > flickingVertically: 0
+------------------ > currentIndex: -1
+------------------ > draggingHorizontally: 0
+------------------ > x: 0.0
+------------------ > z: 0.0
+------------------ > Children: Array([dbus.String(u'QQuickItem'), dbus.String(u'QQuickVisualDataModel'), dbus.String(u'QQuickViewSection'), dbus.String(u'QQuickFlickableVisibleArea'), dbus.String(u'QQuickItem')], signature=None)
+------------------ > interactive: 1
+------------------ > highlightMoveDuration: 150
+------------------ > orientation: 1
+------------------ > clip: 0
+------------------ > effectiveLayoutDirection: 0
+------------------ > enabled: 1
+------------------ > highlightFollowsCurrentItem: 1
+------------------ > implicitHeight: 0.0
+------------------ > snapMode: 0
+------------------ > contentWidth: 0.0
+------------------ > movingVertically: 0
+------------------ > dragging: 0
+------------------ > id: 12
+------------------ > leftMargin: 0.0
+------------------ > scale: 1.0
+------------------ > atXEnd: 1
+------------------ > keyNavigationWraps: 0
+------------------ > activeFocus: 0
+------------------ > state: 
+------------------ > contentY: -0.0
+------------------ > atYBeginning: 1
+------------------ > implicitWidth: 0.0
+------------------ > preferredHighlightBegin: 0.0
+------------------ > highlightMoveVelocity: 400.0
+------------------ > opacity: 1.0
+------------------ > flickDeceleration: 1500.0
+------------------ > rightMargin: 0.0
+------------------ > movingHorizontally: 0
+------------------ > maximumFlickVelocity: 2500.0
+------------------ > spacing: 0.0
+------------------ > originX: 0.0
+------------------ > highlightResizeVelocity: 400.0
+------------------ > horizontalVelocity: 0.0
+------------------ > moving: 0
+------------------ > flickingHorizontally: 0
+------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------ > topMargin: 0.0
+------------------ > antialiasing: 0
+------------------ > _autopilot_id: 12
+------------------ > y: 0.0
+--------------------- QQuickItem '' 
+
+--------------------- > opacity: 1.0
+--------------------- > clip: 0
+--------------------- > enabled: 1
+--------------------- > baselineOffset: 0.0
+--------------------- > focus: 0
+--------------------- > implicitHeight: 0.0
+--------------------- > height: 0.0
+--------------------- > visible: 1
+--------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+--------------------- > rotation: 0.0
+--------------------- > id: 13
+--------------------- > scale: 1.0
+--------------------- > objectName: 
+--------------------- > activeFocus: 0
+--------------------- > antialiasing: 0
+--------------------- > _autopilot_id: 13
+--------------------- > smooth: 1
+--------------------- > transformOrigin: 4
+--------------------- > width: 0.0
+--------------------- > state: 
+--------------------- > implicitWidth: 0.0
+--------------------- > y: 0.0
+--------------------- > x: 0.0
+--------------------- > z: 0.0
+--------------- QQuickMouseArea '' 
+
+--------------- > propagateComposedEvents: 0
+--------------- > clip: 0
+--------------- > enabled: 1
+--------------- > baselineOffset: 0.0
+--------------- > focus: 0
+--------------- > implicitHeight: 0.0
+--------------- > height: 467.0
+--------------- > visible: 1
+--------------- > pressedButtons: 0
+--------------- > id: 10
+--------------- > acceptedButtons: 1
+--------------- > scale: 1.0
+--------------- > activeFocus: 0
+--------------- > transformOrigin: 4
+--------------- > cursorShape: 0
+--------------- > width: 720.0
+--------------- > state: 
+--------------- > implicitWidth: 0.0
+--------------- > containsMouse: 0
+--------------- > opacity: 1.0
+--------------- > objectName: 
+--------------- > mouseY: 0.0
+--------------- > preventStealing: 1
+--------------- > hoverEnabled: 0
+--------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(467, variant_level=1)], signature=None)
+--------------- > rotation: 0.0
+--------------- > antialiasing: 0
+--------------- > _autopilot_id: 10
+--------------- > smooth: 1
+--------------- > pressed: 0
+--------------- > y: 122.0
+--------------- > x: 0.0
+--------------- > z: 0.0
+--------------- > Children: Array([dbus.String(u'QQuickItem'), dbus.String(u'QQuickItem')], signature=None)
+--------------- > mouseX: 0.0
+------------------ QQuickItem '' 
+
+------------------ > opacity: 1.0
+------------------ > clip: 0
+------------------ > enabled: 1
+------------------ > baselineOffset: 0.0
+------------------ > focus: 0
+------------------ > implicitHeight: 0.0
+------------------ > height: 467.0
+------------------ > visible: 1
+------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(467, variant_level=1)], signature=None)
+------------------ > rotation: 0.0
+------------------ > id: 14
+------------------ > scale: 1.0
+------------------ > objectName: 
+------------------ > activeFocus: 0
+------------------ > antialiasing: 0
+------------------ > _autopilot_id: 14
+------------------ > smooth: 1
+------------------ > transformOrigin: 4
+------------------ > width: 720.0
+------------------ > state: 
+------------------ > implicitWidth: 0.0
+------------------ > y: 0.0
+------------------ > x: 0.0
+------------------ > z: 0.0
+------------------ > Children: Array([dbus.String(u'QQuickRectangle'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickItem'), dbus.String(u'Popper_QMLTYPE_4'), dbus.String(u'QQuickItem_QML_8'), dbus.String(u'QQuickRectangle'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickItem'), dbus.String(u'Popper_QMLTYPE_4'), dbus.String(u'QQuickItem_QML_8')], signature=None)
+--------------------- QQuickRectangle '' 
+
+--------------------- > opacity: 1.0
+--------------------- > clip: 0
+--------------------- > color: Array([dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+--------------------- > enabled: 1
+--------------------- > baselineOffset: 0.0
+--------------------- > focus: 0
+--------------------- > implicitHeight: 0.0
+--------------------- > height: 467.0
+--------------------- > visible: 1
+--------------------- > radius: 0.0
+--------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(467, variant_level=1)], signature=None)
+--------------------- > rotation: 0.0
+--------------------- > id: 15
+--------------------- > scale: 1.0
+--------------------- > objectName: 
+--------------------- > activeFocus: 0
+--------------------- > antialiasing: 0
+--------------------- > _autopilot_id: 15
+--------------------- > smooth: 1
+--------------------- > transformOrigin: 4
+--------------------- > width: 720.0
+--------------------- > state: 
+--------------------- > implicitWidth: 0.0
+--------------------- > y: 0.0
+--------------------- > x: 0.0
+--------------------- > z: 0.0
+--------------------- > Children: Array([dbus.String(u'QQuickGradient')], signature=None)
+--------------------- QQuickImage '' 
+
+--------------------- > opacity: 1.0
+--------------------- > clip: 0
+--------------------- > enabled: 1
+--------------------- > baselineOffset: 0.0
+--------------------- > focus: 0
+--------------------- > implicitHeight: 6.0
+--------------------- > height: 6.0
+--------------------- > visible: 1
+--------------------- > asynchronous: 0
+--------------------- > mirror: 0
+--------------------- > id: 16
+--------------------- > scale: 1.0
+--------------------- > activeFocus: 0
+--------------------- > cache: 1
+--------------------- > transformOrigin: 4
+--------------------- > width: 720.0
+--------------------- > state: 
+--------------------- > verticalAlignment: 128
+--------------------- > implicitWidth: 2.0
+--------------------- > progress: 1.0
+--------------------- > sourceSize: Array([dbus.Int32(2, variant_level=1), dbus.Int32(6, variant_level=1)], signature=None)
+--------------------- > status: 1
+--------------------- > objectName: 
+--------------------- > paintedWidth: 720.0
+--------------------- > fillMode: 0
+--------------------- > horizontalAlignment: 4
+--------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(6, variant_level=1)], signature=None)
+--------------------- > rotation: 0.0
+--------------------- > antialiasing: 0
+--------------------- > _autopilot_id: 16
+--------------------- > smooth: 1
+--------------------- > paintedHeight: 6.0
+--------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/border_top.png
+--------------------- > y: 0.0
+--------------------- > x: 0.0
+--------------------- > z: 0.0
+--------------------- > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------- QQuickImage '' 
+
+--------------------- > opacity: 1.0
+--------------------- > clip: 0
+--------------------- > enabled: 1
+--------------------- > baselineOffset: 0.0
+--------------------- > focus: 0
+--------------------- > implicitHeight: 5.0
+--------------------- > height: 5.0
+--------------------- > visible: 1
+--------------------- > asynchronous: 0
+--------------------- > mirror: 0
+--------------------- > id: 17
+--------------------- > scale: 1.0
+--------------------- > activeFocus: 0
+--------------------- > cache: 1
+--------------------- > transformOrigin: 4
+--------------------- > width: 720.0
+--------------------- > state: 
+--------------------- > verticalAlignment: 128
+--------------------- > implicitWidth: 2.0
+--------------------- > progress: 1.0
+--------------------- > sourceSize: Array([dbus.Int32(2, variant_level=1), dbus.Int32(5, variant_level=1)], signature=None)
+--------------------- > status: 1
+--------------------- > objectName: 
+--------------------- > paintedWidth: 720.0
+--------------------- > fillMode: 0
+--------------------- > horizontalAlignment: 4
+--------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(1275, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(5, variant_level=1)], signature=None)
+--------------------- > rotation: 0.0
+--------------------- > antialiasing: 0
+--------------------- > _autopilot_id: 17
+--------------------- > smooth: 1
+--------------------- > paintedHeight: 5.0
+--------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/border_bottom.png
+--------------------- > y: 462.0
+--------------------- > x: 0.0
+--------------------- > z: 0.0
+--------------------- > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------- QQuickItem '' 
+
+--------------------- > opacity: 1.0
+--------------------- > clip: 0
+--------------------- > enabled: 1
+--------------------- > baselineOffset: 0.0
+--------------------- > focus: 0
+--------------------- > implicitHeight: 0.0
+--------------------- > height: 456.0
+--------------------- > visible: 1
+--------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(819, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(456, variant_level=1)], signature=None)
+--------------------- > rotation: 0.0
+--------------------- > id: 18
+--------------------- > scale: 1.0
+--------------------- > objectName: 
+--------------------- > activeFocus: 0
+--------------------- > antialiasing: 0
+--------------------- > _autopilot_id: 18
+--------------------- > smooth: 1
+--------------------- > transformOrigin: 4
+--------------------- > width: 720.0
+--------------------- > state: 
+--------------------- > implicitWidth: 0.0
+--------------------- > y: 6.0
+--------------------- > x: 0.0
+--------------------- > z: 0.0
+--------------------- > Children: Array([dbus.String(u'QQuickRepeater'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickItem_QML_7'), dbus.String(u'QQuickRepeater')], signature=None)
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: q
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(73, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 21
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 21
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 73.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 0.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 57
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(4, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 57
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 4.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'q'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.9375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 123
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.9375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.9375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(26, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(23, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 123
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: q
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 124
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(37, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 124
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 58
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 73.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(73, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 58
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: w
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(73, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 22
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 22
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 73.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 59
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(76, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 59
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'w'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 29.78125
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 125
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 29.78125
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 29.78125
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(94, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(30, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 125
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: w
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 126
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(109, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 126
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 60
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(73, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 60
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: e
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(145, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 23
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 23
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 145.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 61
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(148, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 61
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'e'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.1875
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 127
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.1875
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.1875
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(170, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(22, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 127
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: e
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 128
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(181, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 128
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 62
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(145, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 62
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: r
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(217, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 24
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 24
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 217.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 63
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(220, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 63
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'r'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 16.03125
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 129
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 16.03125
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 16.03125
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(245, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(16, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 129
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: r
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 130
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(253, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 130
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 64
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(217, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 64
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: t
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(289, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 25
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 25
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 289.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 65
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(292, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 65
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u't'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 16.859375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 131
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 16.859375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 16.859375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(317, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(17, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 131
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: t
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 132
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(325, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 132
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 66
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(289, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 66
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: y
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(361, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 26
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 26
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 361.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 67
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(364, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 67
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'y'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 20.78125
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 133
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 20.78125
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 20.78125
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(387, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(21, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 133
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: y
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 134
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(397, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 134
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 68
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(361, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 68
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: u
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(433, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 27
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 27
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 433.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 69
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(436, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 69
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'u'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 135
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(458, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(22, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 135
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: u
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 136
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(469, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 136
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 70
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(433, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 70
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: i
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(505, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 28
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 28
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 505.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 71
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(508, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 71
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'i'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 10.96875
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 137
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 10.96875
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 10.96875
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(536, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(11, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 137
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: i
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 138
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(541, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 138
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 72
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(505, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 72
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: o
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(577, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 29
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 29
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 577.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 73
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(580, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 73
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'o'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 23.0625
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 139
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 23.0625
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 23.0625
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(601, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(23, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 139
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: o
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 140
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(613, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 140
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 74
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(577, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 74
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: p
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(649, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(73, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 30
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 30
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 73.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 24.0
+------------------------ > x: 649.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 75
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(652, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 75
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'p'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.9375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 141
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.9375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.9375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(674, variant_level=1), dbus.Int32(870, variant_level=1), dbus.Int32(23, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 141
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: p
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 142
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(685, variant_level=1), dbus.Int32(892, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 142
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 76
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 73.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(649, variant_level=1), dbus.Int32(843, variant_level=1), dbus.Int32(73, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 76
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: a
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(108, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 31
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 31
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 108.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 0.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 77
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(39, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 77
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 39.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'a'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 21.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 143
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 21.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 21.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(62, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(21, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 143
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: a
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 144
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(72, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 144
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 78
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 108.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(108, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 78
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: s
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(108, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 32
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 32
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 108.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 79
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(111, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 79
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u's'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 18.421875
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 145
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 18.421875
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 18.421875
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(135, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(18, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 145
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: s
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 146
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(144, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 146
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 80
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(108, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 80
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: d
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(180, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 33
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 33
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 180.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 81
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(183, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 81
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'd'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.9375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 147
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.9375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.9375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(205, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(23, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 147
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: d
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 148
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(216, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 148
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 82
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(180, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 82
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: f
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(252, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 34
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 34
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 252.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 83
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(255, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 83
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'f'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 17.03125
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 149
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 17.03125
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 17.03125
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(279, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(17, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 149
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: f
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 150
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(288, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 150
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 84
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(252, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 84
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: g
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(324, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 35
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 35
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 324.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 85
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(327, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 85
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'g'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.5625
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 151
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.5625
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.5625
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(349, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(23, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 151
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: g
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 152
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(360, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 152
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 86
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(324, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 86
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: h
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(396, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 36
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 36
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 396.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 87
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(399, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 87
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'h'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 153
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(421, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(22, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 153
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: h
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 154
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(432, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 154
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 88
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(396, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 88
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: j
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(468, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 37
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 37
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 468.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 89
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(471, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 89
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'j'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 10.96875
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 155
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 10.96875
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 10.96875
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(499, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(11, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 155
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: j
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 156
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(504, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 156
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 90
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(468, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 90
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: k
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(540, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 38
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 38
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 540.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 91
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(543, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 91
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'k'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 157
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(565, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(22, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 157
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: k
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 158
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(576, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 158
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 92
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(540, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 92
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: l
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(612, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(108, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 39
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 39
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 108.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 126.0
+------------------------ > x: 612.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 93
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(615, variant_level=1), dbus.Int32(948, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 93
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'l'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 12.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 159
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 12.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 12.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(642, variant_level=1), dbus.Int32(972, variant_level=1), dbus.Int32(12, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 159
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: l
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 160
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(648, variant_level=1), dbus.Int32(994, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 160
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 94
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 108.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(612, variant_level=1), dbus.Int32(945, variant_level=1), dbus.Int32(108, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 94
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: 
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(95, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 40
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 40
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 95.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 0.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 87.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 95
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 76.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 84.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(84, variant_level=1), dbus.Int32(87, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(4, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(76, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 95
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg_action@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 4.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u''))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 0.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 161
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 0.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 0.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(42, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 161
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: 
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 76.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 28.0
+------------------------------ > height: 28.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 162
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 28.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 28.0
+------------------------------ > progress: 1.0
+------------------------------ > sourceSize: Array([dbus.Int32(28, variant_level=1), dbus.Int32(28, variant_level=1)], signature=None)
+------------------------------ > status: 1
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 28.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(28, variant_level=1), dbus.Int32(1083, variant_level=1), dbus.Int32(28, variant_level=1), dbus.Int32(28, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 162
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 28.0
+------------------------------ > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/icon_shift@18.png
+------------------------------ > y: 32.0
+------------------------------ > x: 24.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 96
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 95.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(95, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 96
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: z
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(95, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(84, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 41
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 41
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 84.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 95.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 97
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(110, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 97
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 15.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'z'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 19.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 163
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 19.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 19.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(134, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(19, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 163
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: z
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 164
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(143, variant_level=1), dbus.Int32(1097, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 164
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 98
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 84.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(95, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(84, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 98
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: x
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(179, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 42
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 42
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 179.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 99
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(182, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 99
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'x'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 21.046875
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 165
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 21.046875
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 21.046875
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(204, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(21, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 165
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: x
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 166
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(215, variant_level=1), dbus.Int32(1097, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 166
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 100
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(179, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 100
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: c
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(251, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 43
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 43
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 251.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 101
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(254, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 101
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'c'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 19.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 167
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 19.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 19.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(278, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(19, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 167
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: c
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 168
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(287, variant_level=1), dbus.Int32(1097, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 168
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 102
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(251, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 102
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: v
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(323, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 44
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 44
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 323.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 103
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(326, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 103
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'v'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 20.890625
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 169
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 20.890625
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 20.890625
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(349, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(21, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 169
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: v
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 170
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(359, variant_level=1), dbus.Int32(1097, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 170
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 104
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(323, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 104
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: b
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(395, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 45
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 45
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 395.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 105
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(398, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 105
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'b'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.9375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 171
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.9375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.9375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(420, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(23, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 171
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: b
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 172
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(431, variant_level=1), dbus.Int32(1097, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 172
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 106
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(395, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 106
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: n
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(467, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 46
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 46
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 72.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 467.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 107
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(470, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 107
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'n'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 22.375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 173
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 22.375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 22.375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(492, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(22, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 173
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: n
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 174
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(503, variant_level=1), dbus.Int32(1097, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 174
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 108
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 72.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(467, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(72, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 108
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: m
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(539, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(84, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 47
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 47
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 84.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 539.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 109
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(542, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 109
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'm'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 32.75
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 175
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 32.75
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 32.75
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(559, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(33, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 175
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: m
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 176
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(575, variant_level=1), dbus.Int32(1097, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 176
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 110
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 84.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(539, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(84, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 110
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: 
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(623, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(95, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 48
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 48
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 95.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 229.0
+------------------------ > x: 623.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 87.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 111
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 76.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 84.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(84, variant_level=1), dbus.Int32(87, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(638, variant_level=1), dbus.Int32(1051, variant_level=1), dbus.Int32(76, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 111
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg_action@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 15.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u''))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 0.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 177
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 0.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 0.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(676, variant_level=1), dbus.Int32(1075, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 177
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: 
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 76.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 26.0
+------------------------------ > height: 26.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 178
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 43.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 43.0
+------------------------------ > progress: 1.0
+------------------------------ > sourceSize: Array([dbus.Int32(43, variant_level=1), dbus.Int32(26, variant_level=1)], signature=None)
+------------------------------ > status: 1
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 43.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(654, variant_level=1), dbus.Int32(1084, variant_level=1), dbus.Int32(43, variant_level=1), dbus.Int32(26, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 178
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 26.0
+------------------------------ > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/icon_backspace@18.png
+------------------------------ > y: 33.0
+------------------------------ > x: 16.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 112
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 95.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(623, variant_level=1), dbus.Int32(1048, variant_level=1), dbus.Int32(95, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 112
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: ?123
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(123, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 49
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 49
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 123.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 332.0
+------------------------ > x: 0.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 87.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 113
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 108.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 84.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(84, variant_level=1), dbus.Int32(87, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(4, variant_level=1), dbus.Int32(1154, variant_level=1), dbus.Int32(108, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 113
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg_action@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 4.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'?123'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 57.5
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 37.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 69.0625
+------------------------------ > contentHeight: 37.0
+------------------------------ > id: 179
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 69.0625
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 69.0625
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(23, variant_level=1), dbus.Int32(1182, variant_level=1), dbus.Int32(69, variant_level=1), dbus.Int32(37, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 179
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 37.0
+------------------------------ > text: ?123
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 108.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 180
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(58, variant_level=1), dbus.Int32(1200, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 180
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 54.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 114
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 123.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(123, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 114
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: /
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(123, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(80, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 50
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 50
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 80.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 332.0
+------------------------ > x: 123.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 115
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(134, variant_level=1), dbus.Int32(1154, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 115
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 11.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'/'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 17.59375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 181
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 17.59375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 17.59375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(158, variant_level=1), dbus.Int32(1178, variant_level=1), dbus.Int32(18, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 181
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: /
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 182
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(167, variant_level=1), dbus.Int32(1200, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 182
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 116
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 80.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(123, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(80, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 116
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: 
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(203, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(312, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 51
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 51
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 312.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 332.0
+------------------------ > x: 203.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 117
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 306.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(206, variant_level=1), dbus.Int32(1154, variant_level=1), dbus.Int32(306, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 117
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u''))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 0.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 183
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 0.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 0.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(359, variant_level=1), dbus.Int32(1178, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 183
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: 
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 306.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 184
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(359, variant_level=1), dbus.Int32(1200, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 184
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 153.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 118
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 312.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(203, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(312, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 118
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: .
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(515, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(80, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 52
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 52
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 80.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 332.0
+------------------------ > x: 515.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 88.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 119
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 66.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 66.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(66, variant_level=1), dbus.Int32(88, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(518, variant_level=1), dbus.Int32(1154, variant_level=1), dbus.Int32(66, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 119
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 3.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u'.'))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 9.34375
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 185
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 9.34375
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 9.34375
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(546, variant_level=1), dbus.Int32(1178, variant_level=1), dbus.Int32(9, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 1
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 185
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: .
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 66.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 0.0
+------------------------------ > height: 0.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 186
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 0.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 0.0
+------------------------------ > progress: 0.0
+------------------------------ > sourceSize: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > status: 0
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 0.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(551, variant_level=1), dbus.Int32(1200, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 186
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 0.0
+------------------------------ > source: 
+------------------------------ > y: 46.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 120
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 80.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(515, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(80, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 120
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickItem '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > text: 
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 98.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(595, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(123, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 53
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 53
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 123.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 332.0
+------------------------ > x: 595.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickMouseArea')], signature=None)
+------------------------ > enabled: 1
+--------------------------- QQuickBorderImage '' 
+
+--------------------------- > opacity: 1.0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 87.0
+--------------------------- > height: 92.0
+--------------------------- > visible: 1
+--------------------------- > asynchronous: 0
+--------------------------- > mirror: 0
+--------------------------- > id: 121
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > cache: 1
+--------------------------- > transformOrigin: 4
+--------------------------- > width: 108.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 84.0
+--------------------------- > progress: 1.0
+--------------------------- > sourceSize: Array([dbus.Int32(84, variant_level=1), dbus.Int32(87, variant_level=1)], signature=None)
+--------------------------- > horizontalTileMode: 0
+--------------------------- > status: 1
+--------------------------- > objectName: 
+--------------------------- > globalRect: Array([dbus.Int32(606, variant_level=1), dbus.Int32(1154, variant_level=1), dbus.Int32(108, variant_level=1), dbus.Int32(92, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 121
+--------------------------- > smooth: 1
+--------------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/keybg_action@18.png
+--------------------------- > verticalTileMode: 0
+--------------------------- > y: 3.0
+--------------------------- > x: 11.0
+--------------------------- > z: 0.0
+--------------------------- > Children: Array([dbus.String(u'QQuickText'), dbus.String(u'QQuickImage'), dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickImage')], signature=None)
+------------------------------ QQuickText '' (String(u''))
+
+------------------------------ > clip: 0
+------------------------------ > truncated: 0
+------------------------------ > color: Array([dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(102, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > smooth: 1
+------------------------------ > baselineOffset: 60.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 44.0
+------------------------------ > height: 92.0
+------------------------------ > fontSizeMode: 0
+------------------------------ > lineCount: 1
+------------------------------ > contentWidth: 0.0
+------------------------------ > contentHeight: 44.0
+------------------------------ > id: 187
+------------------------------ > style: 0
+------------------------------ > scale: 1.0
+------------------------------ > minimumPixelSize: 12
+------------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------------ > activeFocus: 0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > wrapMode: 0
+------------------------------ > implicitWidth: 0.0
+------------------------------ > maximumLineCount: 2147483647
+------------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > lineHeightMode: 0
+------------------------------ > enabled: 1
+------------------------------ > opacity: 1.0
+------------------------------ > effectiveHorizontalAlignment: 4
+------------------------------ > objectName: 
+------------------------------ > minimumPointSize: 12
+------------------------------ > paintedWidth: 0.0
+------------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------------ > horizontalAlignment: 4
+------------------------------ > transformOrigin: 4
+------------------------------ > lineHeight: 1.0
+------------------------------ > globalRect: Array([dbus.Int32(660, variant_level=1), dbus.Int32(1178, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(44, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > visible: 0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 187
+------------------------------ > elide: 3
+------------------------------ > renderType: 0
+------------------------------ > paintedHeight: 44.0
+------------------------------ > text: 
+------------------------------ > y: 0.0
+------------------------------ > x: 0.0
+------------------------------ > textFormat: 2
+------------------------------ > z: 0.0
+------------------------------ > width: 108.0
+------------------------------ QQuickImage '' 
+
+------------------------------ > opacity: 1.0
+------------------------------ > clip: 0
+------------------------------ > enabled: 1
+------------------------------ > baselineOffset: 0.0
+------------------------------ > focus: 0
+------------------------------ > implicitHeight: 29.0
+------------------------------ > height: 29.0
+------------------------------ > visible: 1
+------------------------------ > asynchronous: 0
+------------------------------ > mirror: 0
+------------------------------ > id: 188
+------------------------------ > scale: 1.0
+------------------------------ > activeFocus: 0
+------------------------------ > cache: 1
+------------------------------ > transformOrigin: 4
+------------------------------ > width: 41.0
+------------------------------ > state: 
+------------------------------ > verticalAlignment: 128
+------------------------------ > implicitWidth: 41.0
+------------------------------ > progress: 1.0
+------------------------------ > sourceSize: Array([dbus.Int32(41, variant_level=1), dbus.Int32(29, variant_level=1)], signature=None)
+------------------------------ > status: 1
+------------------------------ > objectName: 
+------------------------------ > paintedWidth: 41.0
+------------------------------ > fillMode: 0
+------------------------------ > horizontalAlignment: 4
+------------------------------ > globalRect: Array([dbus.Int32(639, variant_level=1), dbus.Int32(1185, variant_level=1), dbus.Int32(41, variant_level=1), dbus.Int32(29, variant_level=1)], signature=None)
+------------------------------ > rotation: 0.0
+------------------------------ > antialiasing: 0
+------------------------------ > _autopilot_id: 188
+------------------------------ > smooth: 1
+------------------------------ > paintedHeight: 29.0
+------------------------------ > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/icon_enter@18.png
+------------------------------ > y: 31.0
+------------------------------ > x: 33.0
+------------------------------ > z: 0.0
+------------------------------ > Children: Array([dbus.String(u'UCQQuickImageExtension')], signature=None)
+--------------------------- QQuickMouseArea '' 
+
+--------------------------- > propagateComposedEvents: 0
+--------------------------- > clip: 0
+--------------------------- > enabled: 1
+--------------------------- > baselineOffset: 0.0
+--------------------------- > focus: 0
+--------------------------- > implicitHeight: 0.0
+--------------------------- > height: 98.0
+--------------------------- > visible: 1
+--------------------------- > pressedButtons: 0
+--------------------------- > id: 122
+--------------------------- > acceptedButtons: 1
+--------------------------- > scale: 1.0
+--------------------------- > activeFocus: 0
+--------------------------- > transformOrigin: 4
+--------------------------- > cursorShape: 0
+--------------------------- > width: 123.0
+--------------------------- > state: 
+--------------------------- > implicitWidth: 0.0
+--------------------------- > containsMouse: 0
+--------------------------- > opacity: 1.0
+--------------------------- > objectName: 
+--------------------------- > mouseY: 0.0
+--------------------------- > preventStealing: 0
+--------------------------- > hoverEnabled: 1
+--------------------------- > globalRect: Array([dbus.Int32(595, variant_level=1), dbus.Int32(1151, variant_level=1), dbus.Int32(123, variant_level=1), dbus.Int32(98, variant_level=1)], signature=None)
+--------------------------- > rotation: 0.0
+--------------------------- > antialiasing: 0
+--------------------------- > _autopilot_id: 122
+--------------------------- > smooth: 1
+--------------------------- > pressed: 0
+--------------------------- > y: 0.0
+--------------------------- > x: 0.0
+--------------------------- > z: 0.0
+--------------------------- > mouseX: 0.0
+------------------------ QQuickRepeater '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > enabled: 1
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 0.0
+------------------------ > height: 456.0
+------------------------ > visible: 1
+------------------------ > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(819, variant_level=1), dbus.Int32(720, variant_level=1), dbus.Int32(456, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > id: 54
+------------------------ > count: 33
+------------------------ > scale: 1.0
+------------------------ > objectName: 
+------------------------ > activeFocus: 0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 54
+------------------------ > smooth: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 720.0
+------------------------ > state: 
+------------------------ > implicitWidth: 0.0
+------------------------ > y: 0.0
+------------------------ > x: 0.0
+------------------------ > z: 0.0
+------------------------ > Children: Array([dbus.String(u'QQmlComponent')], signature=None)
+--------------------- Popper '' 
+
+--------------------- > opacity: 0.0
+--------------------- > clip: 0
+--------------------- > enabled: 1
+--------------------- > baselineOffset: 0.0
+--------------------- > focus: 0
+--------------------- > implicitHeight: 120.0
+--------------------- > height: 120.0
+--------------------- > visible: 1
+--------------------- > asynchronous: 0
+--------------------- > mirror: 0
+--------------------- > id: 19
+--------------------- > scale: 1.0
+--------------------- > activeFocus: 0
+--------------------- > cache: 1
+--------------------- > transformOrigin: 4
+--------------------- > width: 80.0
+--------------------- > state: 
+--------------------- > verticalAlignment: 128
+--------------------- > implicitWidth: 80.0
+--------------------- > progress: 1.0
+--------------------- > sourceSize: Array([dbus.Int32(80, variant_level=1), dbus.Int32(120, variant_level=1)], signature=None)
+--------------------- > status: 1
+--------------------- > objectName: 
+--------------------- > paintedWidth: 80.0
+--------------------- > fillMode: 0
+--------------------- > horizontalAlignment: 4
+--------------------- > globalRect: Array([dbus.Int32(0, variant_level=1), dbus.Int32(813, variant_level=1), dbus.Int32(80, variant_level=1), dbus.Int32(120, variant_level=1)], signature=None)
+--------------------- > rotation: 0.0
+--------------------- > antialiasing: 0
+--------------------- > _autopilot_id: 19
+--------------------- > smooth: 1
+--------------------- > paintedHeight: 120.0
+--------------------- > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/popper.png
+--------------------- > y: 0.0
+--------------------- > x: 0.0
+--------------------- > z: 0.0
+--------------------- > Children: Array([dbus.String(u'QQuickTransition'), dbus.String(u'QQuickState'), dbus.String(u'UCQQuickImageExtension'), dbus.String(u'QQuickText'), dbus.String(u'QQuickText')], signature=None)
+------------------------ QQuickText '' (String(u''))
+
+------------------------ > clip: 0
+------------------------ > truncated: 0
+------------------------ > color: Array([dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------ > smooth: 1
+------------------------ > baselineOffset: 42.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 53.0
+------------------------ > height: 53.0
+------------------------ > fontSizeMode: 0
+------------------------ > lineCount: 1
+------------------------ > contentWidth: 0.0
+------------------------ > contentHeight: 53.0
+------------------------ > id: 189
+------------------------ > style: 0
+------------------------ > scale: 1.0
+------------------------ > minimumPixelSize: 12
+------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Popper.qml
+------------------------ > activeFocus: 0
+------------------------ > state: 
+------------------------ > verticalAlignment: 128
+------------------------ > wrapMode: 0
+------------------------ > implicitWidth: 0.0
+------------------------ > maximumLineCount: 2147483647
+------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------ > lineHeightMode: 0
+------------------------ > enabled: 1
+------------------------ > opacity: 1.0
+------------------------ > effectiveHorizontalAlignment: 4
+------------------------ > objectName: 
+------------------------ > minimumPointSize: 12
+------------------------ > paintedWidth: 0.0
+------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------ > horizontalAlignment: 4
+------------------------ > transformOrigin: 4
+------------------------ > lineHeight: 1.0
+------------------------ > globalRect: Array([dbus.Int32(40, variant_level=1), dbus.Int32(846, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(53, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > visible: 1
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 189
+------------------------ > elide: 3
+------------------------ > renderType: 0
+------------------------ > paintedHeight: 53.0
+------------------------ > text: 
+------------------------ > y: 33.0
+------------------------ > x: 40.0
+------------------------ > textFormat: 2
+------------------------ > z: 0.0
+------------------------ > width: 0.0
+--------------------- QQuickItem '' 
+
+--------------------- > opacity: 0.0
+--------------------- > clip: 0
+--------------------- > enabled: 1
+--------------------- > baselineOffset: 0.0
+--------------------- > focus: 0
+--------------------- > implicitHeight: 0.0
+--------------------- > height: 0.0
+--------------------- > visible: 1
+--------------------- > globalRect: Array([dbus.Int32(360, variant_level=1), dbus.Int32(1047, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1)], signature=None)
+--------------------- > rotation: 0.0
+--------------------- > id: 20
+--------------------- > scale: 1.0
+--------------------- > objectName: 
+--------------------- > activeFocus: 0
+--------------------- > antialiasing: 0
+--------------------- > _autopilot_id: 20
+--------------------- > smooth: 1
+--------------------- > transformOrigin: 4
+--------------------- > width: 0.0
+--------------------- > state: 
+--------------------- > implicitWidth: 0.0
+--------------------- > y: 234.0
+--------------------- > x: 360.0
+--------------------- > z: 0.0
+--------------------- > Children: Array([dbus.String(u'QQuickBehavior'), dbus.String(u'QQmlTimer'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickText'), dbus.String(u'QQuickBorderImage'), dbus.String(u'QQuickText')], signature=None)
+------------------------ QQuickBorderImage '' 
+
+------------------------ > opacity: 1.0
+------------------------ > clip: 0
+------------------------ > enabled: 1
+------------------------ > baselineOffset: 0.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 32.0
+------------------------ > height: 94.8000030518
+------------------------ > visible: 1
+------------------------ > asynchronous: 0
+------------------------ > mirror: 0
+------------------------ > id: 55
+------------------------ > scale: 1.0
+------------------------ > activeFocus: 0
+------------------------ > cache: 1
+------------------------ > transformOrigin: 4
+------------------------ > width: 0.0
+------------------------ > state: 
+------------------------ > implicitWidth: 32.0
+------------------------ > progress: 1.0
+------------------------ > sourceSize: Array([dbus.Int32(32, variant_level=1), dbus.Int32(32, variant_level=1)], signature=None)
+------------------------ > horizontalTileMode: 0
+------------------------ > status: 1
+------------------------ > objectName: 
+------------------------ > globalRect: Array([dbus.Int32(360, variant_level=1), dbus.Int32(1000, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(95, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 55
+------------------------ > smooth: 1
+------------------------ > source: file:///usr/share/maliit/plugins/org/maliit/styles/ubuntu/images/background.png
+------------------------ > verticalTileMode: 0
+------------------------ > y: -47.4000015259
+------------------------ > x: 0.0
+------------------------ > z: 1000.0
+------------------------ > Children: Array([dbus.String(u'QQuickScaleGrid'), dbus.String(u'UCQQuickImageExtension')], signature=None)
+------------------------ QQuickText '' (String(u''))
+
+------------------------ > clip: 0
+------------------------ > truncated: 0
+------------------------ > color: Array([dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------ > smooth: 1
+------------------------ > baselineOffset: 63.0
+------------------------ > focus: 0
+------------------------ > implicitHeight: 79.0
+------------------------ > height: 79.0
+------------------------ > fontSizeMode: 0
+------------------------ > lineCount: 1
+------------------------ > contentWidth: 0.0
+------------------------ > contentHeight: 79.0
+------------------------ > id: 56
+------------------------ > style: 0
+------------------------ > scale: 1.0
+------------------------ > minimumPixelSize: 12
+------------------------ > baseUrl: file:///usr/share/maliit/plugins/org/maliit/Keyboard.qml
+------------------------ > activeFocus: 0
+------------------------ > state: 
+------------------------ > verticalAlignment: 32
+------------------------ > wrapMode: 0
+------------------------ > implicitWidth: 0.0
+------------------------ > maximumLineCount: 2147483647
+------------------------ > linkColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------ > lineHeightMode: 0
+------------------------ > enabled: 1
+------------------------ > opacity: 1.0
+------------------------ > effectiveHorizontalAlignment: 1
+------------------------ > objectName: 
+------------------------ > minimumPointSize: 12
+------------------------ > paintedWidth: 0.0
+------------------------ > styleColor: Array([dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(255, variant_level=1)], signature=None)
+------------------------ > horizontalAlignment: 1
+------------------------ > transformOrigin: 4
+------------------------ > lineHeight: 1.0
+------------------------ > globalRect: Array([dbus.Int32(360, variant_level=1), dbus.Int32(1007, variant_level=1), dbus.Int32(0, variant_level=1), dbus.Int32(79, variant_level=1)], signature=None)
+------------------------ > rotation: 0.0
+------------------------ > visible: 1
+------------------------ > antialiasing: 0
+------------------------ > _autopilot_id: 56
+------------------------ > elide: 3
+------------------------ > renderType: 0
+------------------------ > paintedHeight: 79.0
+------------------------ > text: 
+------------------------ > y: -40.0
+------------------------ > x: 0.0
+------------------------ > textFormat: 2
+------------------------ > z: 1001.0
+------------------------ > width: 0.0
+------ QQmlEngine '' 
+
+------ > _autopilot_id: 3
+------ > offlineStoragePath: /home/phablet/.local/share/maliit-server/QML/OfflineStorage
+------ > id: 3
+------ > objectName: 
+------ QQmlComponent '' 
+
+------ > url: file:///usr/share/maliit/plugins/org/maliit/maliit-keyboard.qml
+------ > _autopilot_id: 4
+------ > id: 4
+------ > objectName: 
+------ > progress: 1.0

=== added file 'tests/autopilot/maliit_keyboard/test_app.qml'
--- tests/autopilot/maliit_keyboard/test_app.qml	1970-01-01 00:00:00 +0000
+++ tests/autopilot/maliit_keyboard/test_app.qml	2013-08-13 03:11:49 +0000
@@ -0,0 +1,29 @@
+
+import QtQuick 2.0
+import Ubuntu.Components 0.1
+
+Rectangle {
+    id: window
+    objectName: "windowRectangle"
+    //width: 500
+    //height: 500
+    color: "lightgrey"
+
+    Rectangle {
+        id: inputRectangle
+        width: parent.width
+        height: parent.height / 2
+        color: "white"
+        TextInput {
+            id: input;
+            anchors.fill: parent
+            color: "black";
+            selectionColor: "red"
+
+            // Qt.ImhPreferNumbers
+            inputMethodHints: Qt.ImhNoAutoUppercase | Qt.ImhUrlCharactersOnly | Qt.ImhNoPredictiveText
+            font.pixelSize: units.gu(3)
+            font.bold: false
+        }
+    }
+}

=== added directory 'tests/autopilot/maliit_keyboard/tests'
=== added file 'tests/autopilot/maliit_keyboard/tests/__init__.py'
=== added file 'tests/autopilot/maliit_keyboard/tests/test_keyboard.py'
--- tests/autopilot/maliit_keyboard/tests/test_keyboard.py	1970-01-01 00:00:00 +0000
+++ tests/autopilot/maliit_keyboard/tests/test_keyboard.py	2013-08-13 03:11:49 +0000
@@ -0,0 +1,232 @@
+import os
+
+from testtools.matchers import IsInstance, Equals
+from tempfile import mktemp
+from textwrap import dedent
+
+from autopilot.testcase import AutopilotTestCase
+from autopilot.input import Pointer, Touch
+from autopilot.matchers import Eventually
+
+from maliit_keyboard.emulators.osk import (
+    OSK,
+    KB_STATE_DEFAULT,
+    KB_STATE_SHIFTED,
+)
+
+
+class OSKeyboardTests(AutopilotTestCase):
+    def setUp(self):
+        super(OSKeyboardTests, self).setUp()
+        self.pointer = Pointer(Touch.create())
+
+    # This does 2 things, launches and clicks waiting for the keyboard. Split
+    # this up.
+    def launch_test_input_area(self):
+        self.app = self._launch_simple_input()
+        text_rectangle = self.app.select_single(
+            "QQuickRectangle",
+            objectName='inputRectangle'
+        )
+        text_area = self.app.select_single("QQuickTextInput")
+        self.pointer.click_object(text_rectangle)
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+        self.assertThat(keyboard.is_available, Eventually(Equals(True)))
+
+        return text_area
+
+    def _start_qml_script(self, script_contents):
+        """Launch a qml script."""
+        qml_path = mktemp(suffix='.qml')
+        open(qml_path, 'w').write(script_contents)
+        self.addCleanup(os.remove, qml_path)
+
+        return self.launch_test_application(
+            "qmlscene",
+            qml_path,
+            app_type='qt',
+        )
+
+    def _launch_simple_input(self):
+        simple_script = dedent("""
+        import QtQuick 2.0
+        import Ubuntu.Components 0.1
+
+        Rectangle {
+            id: window
+            objectName: "windowRectangle"
+            //width: 500
+            //height: 500
+            color: "lightgrey"
+
+            Rectangle {
+                objectName: "inputRectangle"
+                width: parent.width
+                height: parent.height / 2
+                color: "white"
+                TextInput {
+                    id: input;
+                    anchors.fill: parent
+                    color: "black";
+                    selectionColor: "red"
+
+                    // Qt.ImhPreferNumbers
+                    inputMethodHints: Qt.ImhNoAutoUppercase | Qt.ImhUrlCharactersOnly | Qt.ImhNoPredictiveText
+                    font.pixelSize: units.gu(3)
+                    font.bold: false
+                }
+            }
+        }
+
+        """)
+
+        return self._start_qml_script(simple_script)
+
+
+class OSKeyboardTestsAccess(OSKeyboardTests):
+
+    def test_can_create_keyboard(self):
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+        self.assertThat(keyboard, IsInstance(OSK))
+
+    def test_keyboard_is_available(self):
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+        app = self._launch_simple_input()
+        text_rectangle = app.select_single(
+            "QQuickRectangle",
+            objectName='inputRectangle'
+        )
+
+        self.pointer.click_object(text_rectangle)
+
+        self.assertThat(keyboard.is_available, Eventually(Equals(True)))
+
+
+class OSKeyboardTypingTests(OSKeyboardTests):
+
+    scenarios = [
+        ('lower_alpha', dict(input='abcdefghijklmnopqrstuvwxyz')),
+        ('upper_alpha', dict(input='ABCDEFGHIJKLMNOPQRSTUVWXYZ')),
+        ('numeric', dict(input='0123456789')),
+        ('punctuation', dict(input='`~!@#$%^&*()_-+={}[]|\\:;"\'<>,.?/'))
+    ]
+
+    def test_can_type_string(self):
+        text_area = self.launch_test_input_area()
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+
+        keyboard.type(self.input)
+
+        self.assertThat(text_area.text, Eventually(Equals(self.input)))
+
+
+class OSKeyboardStateChanges(OSKeyboardTests):
+
+    def test_keyboard_layout_starts_shifted(self):
+        """When first launched the keyboard state must be
+        shifted/capitalised.
+
+        """
+        text_area = self.launch_test_input_area()
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+
+        self.assertThat(
+            keyboard.keyboard.layoutState,
+            Eventually(Equals(KB_STATE_SHIFTED))
+        )
+
+    def test_shift_latch(self):
+        """Double tap of the shift key must lock it 'On' until the shift key
+        tapped again.
+
+        Normally hitting shift then a letter reverts from the shifted state
+        back to the default. If double clicked it should stay in the shifted
+        until the shift key is clicked again.
+
+        """
+        text_area = self.launch_test_input_area()
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+
+        keyboard.type('abc')
+        keyboard._press_special_key('SHIFT')
+        keyboard._press_special_key('SHIFT')
+        keyboard.type('S')
+
+        self.assertThat(
+            keyboard.keyboard.layoutState,
+            Eventually(Equals(KB_STATE_SHIFTED))
+        )
+        self.assertThat(text_area.text, Eventually(Equals('abcS')))
+
+    def test_shift_state_returns_to_default_after_letter_typed(self):
+        """Pushing shift and then typing an uppercase letter must automatically
+        shift the keyboard back into the default state.
+
+        """
+        text_area = self.launch_test_input_area()
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+
+        # Normally, type and (press_key) take care of shifting into the correct
+        # state, we do it manually here as that's what we're testing.
+        keyboard.type('abc')
+        keyboard._press_special_key('SHIFT')
+        keyboard.type('A')
+
+        # Once the capital letter has been typed, we must be able to access the
+        # lowercase letters, otherwise it's not in the correct state.
+        self.assertThat(
+            keyboard.keyboard.layoutState,
+            Eventually(Equals(KB_STATE_DEFAULT))
+        )
+
+        self.assertThat(text_area.text, Eventually(Equals('abcA')))
+
+    # Note: this is a failing test.
+    # Note: Based of UX design spec.
+    def test_shift_state_entered_after_fullstop(self):
+        """After typing a fullstop the keyboard state must automatically
+        enter the shifted state.
+
+        """
+        text_area = self.launch_test_input_area()
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+
+        keyboard.type("abc.")
+
+        self.assertThat(
+            text_area.text,
+            Eventually(Equals("abc."))
+        )
+
+        self.assertThat(
+            keyboard.keyboard.layoutState,
+            Eventually(Equals(KB_STATE_SHIFTED))
+        )
+
+    def test_switching_between_states(self):
+        text_area = self.launch_test_input_area()
+        keyboard = OSK()
+        self.addCleanup(keyboard.dismiss)
+
+        keyboard.type(
+            'This shouldd\b type & display different  \bCHARs (characters).'
+        )
+
+        expected = "This should type & display different CHARs (characters)."
+        self.assertThat(
+            text_area.text,
+            Eventually(Equals(expected))
+        )
+
+
+# Then add test for specific things, extend test_app so that it has a url
+# element and a password element so that we can type in that and test the
+# results. . .

=== added file 'tests/autopilot/setup.py'
--- tests/autopilot/setup.py	1970-01-01 00:00:00 +0000
+++ tests/autopilot/setup.py	2013-08-13 03:11:49 +0000
@@ -0,0 +1,32 @@
+#!/usr/bin/python
+# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
+#
+# Maliit-keyboard Autopilot Test Suite
+# Copyright (C) 2012-2013 Canonical
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+
+
+from distutils.core import setup
+from setuptools import find_packages
+
+setup(
+    name='maliit_keyboard',
+    version='1.0',
+    description='Maliit-keyboard autopilot tests and emulators.',
+    url='https://launchpad.net/',
+    license='GPLv3',
+    packages=find_packages(),
+)

